==> hbase-server-1.4.14-test-sources.jar: org/apache/hadoop/hbase/wal/TestWALSplitBoundedLogWriterCreation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hbase.wal;

import org.apache.hadoop.hbase.testclassification.LargeTests;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.experimental.categories.Category;

@Category(LargeTests.class)
public class TestWALSplitBoundedLogWriterCreation extends TestWALSplit{
  @BeforeClass
  public static void setUpBeforeClass() throws Exception {
    TestWALSplit.setUpBeforeClass();
    TEST_UTIL.getConfiguration().setBoolean(WALSplitter.SPLIT_WRITER_CREATION_BOUNDED, true);
  }

  /**
   * The logic of this test is conflict with the limit writers split logic, skip this test
   */
  @Test(timeout=300000)
  @Ignore
  public void testThreadingSlowWriterSmallBuffer() throws Exception {
    super.testThreadingSlowWriterSmallBuffer();
  }
}

==> hbase-server-2.1.3-test-sources.jar: org/apache/hadoop/hbase/wal/TestWALSplitBoundedLogWriterCreation.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.wal;

import org.apache.hadoop.hbase.HBaseClassTestRule;
import org.apache.hadoop.hbase.testclassification.LargeTests;
import org.junit.BeforeClass;
import org.junit.ClassRule;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.experimental.categories.Category;

@Category(LargeTests.class)
public class TestWALSplitBoundedLogWriterCreation extends TestWALSplit{

  @ClassRule
  public static final HBaseClassTestRule CLASS_RULE =
      HBaseClassTestRule.forClass(TestWALSplitBoundedLogWriterCreation.class);

  @BeforeClass
  public static void setUpBeforeClass() throws Exception {
    TestWALSplit.setUpBeforeClass();
    TEST_UTIL.getConfiguration().setBoolean(WALSplitter.SPLIT_WRITER_CREATION_BOUNDED, true);
  }

  /**
   * The logic of this test has conflict with the limit writers split logic, skip this test
   */
  @Override
  @Test
  @Ignore
  public void testThreadingSlowWriterSmallBuffer() throws Exception {
    super.testThreadingSlowWriterSmallBuffer();
  }
}
